require 'spec_helper'
require 'active_record'

describe ActiveConnection do
  before(:all) do
    PG_SPEC = {
      adapter:  'postgresql',
      host:     'localhost',
      database: 'schema_test'
    }

    ActiveRecord::Base.establish_connection(PG_SPEC.merge(database: 'postgres'))
    ActiveRecord::Base.connection.drop_database('schema_test')
    ActiveRecord::Base.connection.create_database('schema_test')
    ActiveRecord::Base.establish_connection(PG_SPEC)
    ActiveRecord::Base.connection.create_schema('nonsense')
  end

  it 'changes the schema search path inside the block' do
    ActiveConnection.schema_search_path('nonsense') do
      expect(ActiveRecord::Base.connection.schema_search_path).to eq('nonsense')
    end
  end

  it 'resets the schema search path after the block has executed' do
    original_search_path = ActiveRecord::Base.connection.schema_search_path

    ActiveConnection.schema_search_path('nonsense') { }

    expect(ActiveRecord::Base.connection.schema_search_path).to eq(original_search_path)
  end

  it 'resets the schema search path after an error has occurred' do
    original_search_path = ActiveRecord::Base.connection.schema_search_path
    ActiveConnection.schema_search_path('nonsense') { break }

    expect(ActiveRecord::Base.connection.schema_search_path).to eq(original_search_path)
  end
end
